/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2020 All Rights Reserved.
 */

package com.abssqr.plat.common.model.convertor;

import com.abssqr.plat.common.dal.mysql.auto.dao.AstPackDAO;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.AstPackDO;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.AstPoolDO;
import com.abssqr.plat.common.facade.enums.AstPackStatusEnum;
import com.abssqr.plat.common.facade.enums.AstPackTypeEnum;
import com.abssqr.plat.common.facade.enums.AstTypeEnum;
import com.abssqr.plat.common.facade.param.ast.AstPackOprParam;
import com.abssqr.plat.common.model.domain.ast.AstPack;
import com.abssqr.plat.common.model.domain.ast.AstPoolEntity;
import com.general.system.common.model.Money;

import java.nio.file.OpenOption;
import java.util.Optional;

/**
 *
 * @author xiachenxiang
 * @version com.abssqr.plat.common.model.convertor: AstPackConvert.java, v 0.1 2020-04-18 3:47 PM xiachenxiang Exp $ 
 */
public class AstPackConvert {
    public static AstPack convertDomain(AstPackDO param) {
        if (param == null) {
            return null;
        }
        AstPack result = new AstPack();

        //avalAmt 规模
        result.setAvalAmt(Money.createWithCent(param.getAvalAmt()));
        //type 资产包类型: 1. 正常 NORMAL 2.默认(虚拟) DEFAULT
        result.setType(AstPackTypeEnum.getByCode(param.getType()));
        //packNo 资产包编号
        result.setPackNo(param.getPackNo());
        //planNo 产品编号
        result.setPlanNo(param.getPlanNo());
        //status 状态 1.初始化 INIT 2.筛选中 EXEC 3.筛选完成 SCREEN_FIS  4.已封包 PACK 5.已解包 UNPACK 6.已拆包 BREAK 7.已发行 PUBLISH
        result.setStatus(AstPackStatusEnum.getByCode(param.getStatus()));
        //packName 资产包名称
        result.setPackName(param.getPackName());
        //astPoolNo 资产池编号
        result.setAstPoolNo(param.getAstPoolNo());
        //packDate 封包日
        result.setPackDate(param.getPackDate());
        //packSubmitDate 封包提交日
        result.setPackSubmitDate(param.getPackSubmitDate());
        return result;
    }

    public static AstPackDO convertDO(AstPack param) {
        if (param == null) {
            return null;
        }
        AstPackDO result = new AstPackDO();

        //avalAmt 规模
        result.setAvalAmt(Optional.ofNullable(param.getAvalAmt()).map(Money::getCent).orElse(null));
        //type 资产包类型: 1. 正常 NORMAL 2.默认(虚拟) DEFAULT
        result.setType(Optional.ofNullable(param.getType()).map(AstPackTypeEnum::getCode).orElse(null));
        //packNo 资产包编号
        result.setPackNo(param.getPackNo());
        //planNo 产品编号
        result.setPlanNo(param.getPlanNo());
        //status 状态 1.初始化 INIT 2.筛选中 EXEC 3.筛选完成 SCREEN_FIS  4.已封包 PACK 5.已解包 UNPACK 6.已拆包 BREAK 7.已发行 PUBLISH
        result.setStatus(Optional.ofNullable(param.getStatus()).map(AstPackStatusEnum::getCode).orElse(null));
        //packName 资产包名称
        result.setPackName(param.getPackName());
        //astPoolNo 资产池编号
        result.setAstPoolNo(param.getAstPoolNo());
        //packDate 封包日
        result.setPackDate(param.getPackDate());
        //packSubmitDate 封包提交日
        result.setPackSubmitDate(param.getPackSubmitDate());

        result.setAstTypeCode(Optional.ofNullable(param.getAstTypeCode()).map(AstTypeEnum::getCode).orElse(null));
        return result;
    }
}